# LoadFocus API Client

A command-line interface and JavaScript client library for interacting with the LoadFocus Load Testing API.

## Installation

### Global Installation

```bash
npm install -g @loadfocus/loadfocus-api-client
```

### Local Project Installation

```bash
npm install @loadfocus/loadfocus-api-client
```

### Using with npx

```bash
npx @loadfocus/loadfocus-api-client <command>
```

## Configuration

Before using the client, you need to configure your API key and team ID:

```bash
loadfocus-api config set --apikey YOUR_API_KEY --teamid YOUR_TEAM_ID
```

You can also set a custom API base URL if needed (the default is https://loadfocus.com):

```bash
loadfocus-api config set --url https://your-custom-api-url.com
```

View your current configuration:

```bash
loadfocus-api config show
```

## CLI Usage

### Execute a JMeter Test

```bash
loadfocus-api jmeter execute --name "my-test-name"
```

### Check Test Status

```bash
loadfocus-api jmeter status --name "my-test-name" --id "test-id"
```

### Get Test Results

```bash
loadfocus-api jmeter results --name "my-test-name" --id "test-id"
```

### Run a Test and Evaluate Against Thresholds

```bash
loadfocus-api jmeter run-test --name "my-test-name" --thresholds "avgresponse<=200,errors==0,p95<=250"
```

### Run Multiple Tests from a Configuration File

```bash
loadfocus-api jmeter run-tests --config path/to/tests-config.json
```

Example configuration file (JSON):

```json
{
  "mode": "sequential",
  "tests": [
    {
      "name": "Test1",
      "thresholds": {
        "avgresponse": {
          "operator": "<=",
          "value": 200
        },
        "errors": {
          "operator": "==",
          "value": 0
        }
      }
    },
    {
      "name": "Test2",
      "thresholds": {
        "avgresponse": {
          "operator": "<=",
          "value": 150
        }
      }
    }
  ]
}
```

Or with YAML:

```yaml
mode: sequential
tests:
  - name: Test1
    thresholds:
      avgresponse:
        operator: "<="
        value: 200
      errors:
        operator: "=="
        value: 0
  - name: Test2
    thresholds:
      avgresponse:
        operator: "<="
        value: 150
```

## Using as a Library

```javascript
const { jmeterService } = require('@loadfocus/loadfocus-api-client');

async function runMyTest() {
  const client = jmeterService.createClient({
    apiKey: 'your-api-key',
    teamId: 'your-team-id'
  });
  
  // Execute a test
  const executeResult = await jmeterService.commands.execute({
    name: 'my-test-name'
  });
  
  console.log(`Test started with ID: ${executeResult.testId}`);
}

runMyTest().catch(console.error);
```

## Available Commands

- `config`: Manage configuration settings
- `jmeter execute`: Execute a JMeter test
- `jmeter status`: Get the status of a JMeter test
- `jmeter results`: Get results from a JMeter test
- `jmeter runs`: Get recent test runs
- `jmeter labels`: Get labels from a JMeter test
- `jmeter plan`: Get your current plan information
- `jmeter config`: Get configuration of a JMeter test
- `jmeter run-test`: Execute a test, wait for completion, and evaluate results against thresholds
- `jmeter run-tests`: Execute multiple tests from a configuration file, either sequentially or in parallel

## License

MIT