#!/usr/bin/env node

/**
 * LoadFocus API Client CLI
 * Command-line interface for the LoadFocus API
 */
const { program } = require('commander');
const chalk = require('chalk');
const packageJson = require('../package.json');
const cli = require('../src/cli');
const configCommand = require('../src/cli/commands/config');

// Set up the program
program
    .version(packageJson.version)
    .description('LoadFocus API Client - Command-line interface for LoadFocus API services');

// Configuration commands
program
    .command('config')
    .description('Manage configuration settings')
    .option('set', 'Set configuration values')
    .option('show', 'Show current configuration')
    .option('--apikey <apikey>', 'API key for authentication')
    .option('--teamid <teamid>', 'Your team ID')
    .option('--url <url>', 'API base URL (optional)')
    .action(configCommand);

// Register service-specific commands
cli.registerCommands(program);

// Handle unknown commands
program.on('command:*', () => {
    console.error(chalk.red(`\nError: Invalid command: ${program.args.join(' ')}`));
    console.log(`See ${chalk.blue('--help')} for a list of available commands.\n`);
    process.exit(1);
});

// Execute the command
program.parse(process.argv);

// Show help if no arguments
if (!process.argv.slice(2).length) {
    program.outputHelp();
}