# LoadFocus API Client - Multiple Tests Execution

This directory contains example configuration files for running multiple tests using the `run-tests` command.

## Configuration File Format

The configuration file can be in either JSON or YAML format and should follow this structure:

```json
{
  "mode": "sequential",
  "tests": [
    {
      "name": "Test Name 1",
      "thresholds": {
        "metric1": {
          "operator": "<=",
          "value": 200
        },
        "metric2": {
          "operator": "==",
          "value": 0
        }
      }
    },
    {
      "name": "Test Name 2",
      "thresholds": {
        "metric1": {
          "operator": "<=",
          "value": 150
        }
      }
    }
  ]
}
```

### Configuration Options

- `mode`: Execution mode, either `sequential` (run tests one after another) or `parallel` (run all tests simultaneously)
- `tests`: Array of test configurations
  - `name`: Name of the test to execute
  - `thresholds`: Object containing threshold configurations for metrics
    - Each metric has an `operator` and `value` property
    - Supported operators: `<=`, `<`, `>=`, `>`, `==`, `!=`

## Available Metrics

The following metrics can be used in thresholds:

- `avgresponse`: Average response time (ms)
- `minresponse`: Minimum response time (ms)
- `maxresponse`: Maximum response time (ms)
- `p90`: 90th percentile response time (ms)
- `p95`: 95th percentile response time (ms)
- `p99`: 99th percentile response time (ms)
- `errors`: Error count
- `errorrate`: Error rate (%)
- `throughput`: Throughput (requests/sec)
- `hitspersec`: Hits per second
- `samples`: Sample count

## Usage Examples

### Running tests sequentially from a JSON configuration file:

```bash
loadfocus-api jmeter run-tests --config examples/tests-config.json
```

### Running tests with custom timeout and polling intervals:

```bash
loadfocus-api jmeter run-tests --config examples/tests-config.yaml --wait-timeout 3600 --poll-interval 30 --results-interval 60
```

### Getting JSON output:

```bash
loadfocus-api jmeter run-tests --config examples/tests-config.json --format json
```

## Command Options

- `--config <file>`: Path to the configuration file (JSON or YAML) [required]
- `--wait-timeout <seconds>`: Maximum time to wait for completion in seconds (default: 1800)
- `--poll-interval <seconds>`: How often to check status in seconds (default: 10)
- `--results-interval <seconds>`: How often to show interim results in seconds (default: 30)
- `--format <format>`: Output format: pretty, json (default: "pretty")
