/**
 * JMeter test configuration endpoint
 */

/**
 * Get the configuration of a JMeter test
 * @param {Object} client - JMeter client instance
 * @param {Object} options - Config options
 * @param {string} options.testrunname - Name of the test
 * @returns {Promise<Object>} The test configuration
 */
async function getTestConfig(client, options) {
    if (!options.testrunname) {
        throw new Error('Test name is required');
    }

    try {
        return await client.getConfig({
            testrunname: options.testrunname
        });
    } catch (error) {
        if (error.status === 404) {
            throw new Error(`Configuration for test '${options.testrunname}' not found`);
        }
        throw error;
    }
}

module.exports = getTestConfig;