/**
 * JMeter test execution endpoint
 */

/**
 * Execute a JMeter test
 * @param {Object} client - JMeter client instance
 * @param {Object} options - Test execution options
 * @param {string} options.testrunname - Name of the test to execute
 * @param {string} [options.testrunid] - Optional test run ID
 * @returns {Promise<Object>} The execution response
 */
async function executeTest(client, options) {
    if (!options.testrunname) {
        throw new Error('Test name is required');
    }

    try {
        return await client.execute({
            testrunname: options.testrunname,
            testrunid: options.testrunid
        });
    } catch (error) {
        console.log(error);
        if (error.status === 400 && error.data && error.data.error) {
            const errorReason = error.data.error;

            // Map error codes to more user-friendly messages
            const errorMessages = {
                'number-of-test-parallel-exceeded': 'Maximum number of parallel tests exceeded for your plan.',
                'number-of-daily-tests-exceeded': 'Daily test limit exceeded for your plan.',
                'number-of-yearly-tests-exceeded': 'Yearly test limit exceeded for your plan.',
                'missing-plan': 'No active plan found. Please upgrade your plan.',
                'concurrent-users-exceeded': 'The test exceeds the concurrent users limit for your plan.',
                'failed-to-run': 'The test failed to run. Please check the test configuration.',
                'not-able-to-validate': 'Unable to validate test limits. Please try again later.'
            };

            const message = errorMessages[errorReason] || `Execution failed: ${errorReason}`;
            const executionError = new Error(message);
            executionError.code = errorReason;
            executionError.status = error.status;
            throw executionError;
        }

        throw error;
    }
}

module.exports = executeTest;