/**
 * JMeter test labels endpoint
 */

/**
 * Get labels from a JMeter test
 * @param {Object} client - JMeter client instance
 * @param {Object} options - Labels options
 * @param {string} options.testrunname - Name of the test
 * @param {string} options.testrunid - Test run ID
 * @returns {Promise<Array>} The list of test labels
 */
async function getTestLabels(client, options) {
    if (!options.testrunname) {
        throw new Error('Test name is required');
    }

    if (!options.testrunid) {
        throw new Error('Test ID is required');
    }

    try {
        return await client.getLabels({
            testrunname: options.testrunname,
            testrunid: options.testrunid
        });
    } catch (error) {
        if (error.status === 404) {
            throw new Error(`Labels for test '${options.testrunname}' with ID '${options.testrunid}' not found`);
        }
        throw error;
    }
}

module.exports = getTestLabels;