/**
 * JMeter test results endpoint
 */

/**
 * Get results from a JMeter test
 * @param {Object} client - JMeter client instance
 * @param {Object} options - Results options
 * @param {string} options.testrunname - Name of the test
 * @param {string} options.testrunid - Test run ID
 * @param {number} [options.from] - Start time in milliseconds
 * @param {number} [options.to] - End time in milliseconds
 * @param {string} [options.granularity='1s'] - Result granularity
 * @param {Array<string>} [options.include] - Fields to include
 * @param {Array<string>} [options.filter] - Labels to filter
 * @param {Array<string>} [options.sortasc] - Fields to sort ascending
 * @param {Array<string>} [options.sortdesc] - Fields to sort descending
 * @param {number} [options.batchsize=1000] - Batch size
 * @param {number} [options.skipsize=0] - Skip size
 * @returns {Promise<Object>} The test results
 */
async function getTestResults(client, options) {
    if (!options.testrunname) {
        throw new Error('Test name is required');
    }

    if (!options.testrunid) {
        throw new Error('Test ID is required');
    }

    // Default fields to include if not specified
    const defaultIncludes = [
        'timestamp',
        'mean',
        'median',
        'p90',
        'p95',
        'p99',
        'min',
        'max',
        'ep',
        'rt',
        'l',
        'ct',
        'ec',
        'ecnt',
        'th',
        'kbrs',
        'kbss',
        'sd',
        'label',
        'url',
        'statscnt',
        'no'
    ];

    try {

        let resultsPayload = {
            testrunname: options.testrunname,
            testrunid: options.testrunid,
            // from: options.from || 0,
            // to: options.to || 0,
            granularity: options.granularity || 'none',
            include: options.include || defaultIncludes,
            filter: options.filter || 'HTTP Request3',
            sortasc: options.sortasc || 'timestamp',
            sortdesc: options.sortdesc || 'no',
            batchsize: options.batchsize || 1,
            skipsize: options.skipsize || 0
        };

        return await client.getResults(resultsPayload);
    } catch (error) {
        if (error.status === 404) {
            throw new Error(`Results for test '${options.testrunname}' with ID '${options.testrunid}' not found`);
        }
        throw error;
    }
}

module.exports = getTestResults;