/**
 * JMeter test status endpoint
 */

/**
 * Get the status of a JMeter test
 * @param {Object} client - JMeter client instance
 * @param {Object} options - Status options
 * @param {string} options.testrunname - Name of the test
 * @param {string} options.testrunid - Test run ID
 * @returns {Promise<Object>} The test status
 */
async function getTestStatus(client, options) {
    if (!options.testrunname) {
        throw new Error('Test name is required');
    }

    if (!options.testrunid) {
        throw new Error('Test ID is required');
    }

    try {
        return await client.getStatus({
            testrunname: options.testrunname,
            testrunid: options.testrunid
        });
    } catch (error) {
        if (error.status === 404) {
            throw new Error(`Test '${options.testrunname}' with ID '${options.testrunid}' not found`);
        }
        throw error;
    }
}

module.exports = getTestStatus;