/**
 * JMeter Service
 * 
 * This module exports the JMeter service functionality.
 */

const JMeterClient = require('./client');

// Import commands
const executeCommand = require('./commands/execute');
const statusCommand = require('./commands/status');
const resultsCommand = require('./commands/results');
const runsCommand = require('./commands/runs');
const labelsCommand = require('./commands/labels');
const planCommand = require('./commands/plan');
const configCommand = require('./commands/config');
const runTest = require('./commands/runtest');
const runTests = require('./commands/runtests');

// Export the client and commands
module.exports = {
    JMeterClient,
    commands: {
        execute: executeCommand,
        status: statusCommand,
        results: resultsCommand,
        runs: runsCommand,
        labels: labelsCommand,
        plan: planCommand,
        config: configCommand,
        runTest: runTest,
        runTests: runTests
    },

    /**
     * Create a new JMeter client with the provided options
     * @param {Object} options - Client options
     * @returns {JMeterClient} A configured JMeter client
     */
    createClient: (options = {}) => {
        return new JMeterClient(options);
    }
};