/**
 * JMeter CLI command
 */
const jmeterService = require('../../api/services/jmeter');

/**
 * Register JMeter commands
 * @param {Object} parentCommand - Parent commander instance
 */
function registerJMeterCommands(parentCommand) {
    const jmeterCommand = parentCommand
        .command('jmeter')
        .description('JMeter load testing commands');

    // Execute command
    jmeterCommand
        .command('execute')
        .description('Execute a JMeter test')
        .requiredOption('--name <testname>', 'Name of the test to execute')
        .option('--id <testid>', 'Optional test ID')
        .option('--format <format>', 'Output format: pretty, json, or raw (default: "pretty")')
        .action(jmeterService.commands.execute);

    // Status command
    // In src/cli/commands/jmeter.js

    // Status command
    jmeterCommand
        .command('status')
        .description('Get the status of a JMeter test')
        .requiredOption('--name <testname>', 'Name of the test')
        .requiredOption('--id <testid>', 'Test ID')
        .option('--format <format>', 'Output format: pretty, json, or raw (default: "pretty")')
        .action(jmeterService.commands.status);

    // Results command
    jmeterCommand
        .command('results')
        .description('Get results from a JMeter test')
        .requiredOption('--name <testname>', 'Name of the test')
        .requiredOption('--id <testid>', 'Test ID')
        .option('--from <timestamp>', 'Start timestamp')
        .option('--to <timestamp>', 'End timestamp')
        .option('--granularity <value>', 'Result granularity (default: "1s")')
        .option('--filter <label>', 'Filter results by label (e.g., "HTTP Request3")')
        .option('--format <format>', 'Output format: summary, json, or raw (default: "summary")')
        .action(jmeterService.commands.results);

    // Runs command
    jmeterCommand
        .command('runs')
        .description('Get recent test runs')
        .option('--term <searchterm>', 'Search term (optional)')
        .action(jmeterService.commands.runs);

    // Labels command
    // In src/cli/commands/jmeter.js

    // Labels command
    jmeterCommand
        .command('labels')
        .description('Get labels from a JMeter test')
        .requiredOption('--name <testname>', 'Name of the test')
        .requiredOption('--id <testid>', 'Test ID')
        .option('--format <format>', 'Output format: pretty, json, or raw (default: "pretty")')
        .action(jmeterService.commands.labels);

    // Plan command
    jmeterCommand
        .command('plan')
        .description('Get your current plan information')
        .action(jmeterService.commands.plan);

    // Config command
    jmeterCommand
        .command('config')
        .description('Get configuration of a JMeter test')
        .requiredOption('--name <testname>', 'Name of the test')
        .action(jmeterService.commands.config);

    jmeterCommand
        .command('run-test')
        .description('Execute a test, wait for completion, and evaluate results against thresholds')
        .requiredOption('--name <testname>', 'Name of the test to execute')
        .option('--id <testid>', 'Optional test ID (if not provided, a new test will be executed)')
        .option('--threshold <ms>', 'Response time threshold in ms (legacy, same as --thresholds avgresponse<=value)')
        .option('--thresholds <list>', 'Comma-separated list of thresholds, e.g. "avgresponse<=100,errors=0,p95<200"')
        .option('--wait-timeout <seconds>', 'Maximum time to wait for completion in seconds (default: 1800)', '1800')
        .option('--poll-interval <seconds>', 'How often to check status in seconds (default: 10)', '10')
        .option('--results-interval <seconds>', 'How often to show interim results in seconds (default: 30)', '30')
        .option('--format <format>', 'Output format: pretty, json (default: "pretty")')
        .action(jmeterService.commands.runTest);

    jmeterCommand
        .command('run-tests')
        .description('Execute multiple tests from a configuration file, either sequentially or in parallel')
        .requiredOption('--config <file>', 'Path to the configuration file (JSON or YAML)')
        .option('--wait-timeout <seconds>', 'Maximum time to wait for completion in seconds (default: 1800)', '1800')
        .option('--poll-interval <seconds>', 'How often to check status in seconds (default: 10)', '10')
        .option('--results-interval <seconds>', 'How often to show interim results in seconds (default: 30)', '30')
        .option('--format <format>', 'Output format: pretty, json (default: "pretty")')
        .action(jmeterService.commands.runTests);

    return jmeterCommand;
}

module.exports = registerJMeterCommands;