/**
 * LoadFocus API Client
 * 
 * Main entry point for the LoadFocus API Client library
 */
const jmeterService = require('./api/services/jmeter');
const configManager = require('./config/config-manager');

/**
 * Create and configure a client for a specific service
 * @param {string} service - Service name ('jmeter', 'load', 'speed', etc.)
 * @param {Object} options - Client options
 * @returns {Object} Service client instance
 */
function createClient(service, options = {}) {
    // Get API key and team ID from config if not provided in options
    const apiKey = options.apiKey || configManager.get('apiKey');
    const teamId = options.teamId || configManager.get('teamId');
    const apiUrl = options.apiUrl || configManager.get('apiUrl');

    const clientOptions = {
        apiKey,
        teamId,
        apiUrl
    };

    // Create client for the requested service
    switch (service.toLowerCase()) {
    case 'jmeter':
        return jmeterService.createClient(clientOptions);
        // Add more services here as they are implemented
    default:
        throw new Error(`Unknown service: ${service}. Available services: jmeter`);
    }
}

// Export the public API
module.exports = {
    createClient,
    configManager,
    services: {
        jmeter: jmeterService
    }
};